@@ -1,17 +1,22 @@
 /* apps/asn1pars.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -50,7 +61,7 @@
 #include <string.h>
 #include "apps.h"
 #include "err.h"
-#include "buffer.h"
+#include "envelope.h"
 #include "x509.h"
 #include "pem.h"
 
@@ -73,7 +84,7 @@ char **argv;
 	int i,badops=0,offset=0,ret=1;
 	unsigned int length=0;
 	long num;
-	BIO *in=NULL,*out=NULL;
+	BIO *in=NULL,*out=NULL,*b64=NULL;
 	int informat;
 	char *infile,*str=NULL,*prog;
 	BUF_MEM *buf=NULL;
@@ -115,7 +126,7 @@ char **argv;
 			}
 		else
 			{
-			fprintf(stderr,"unknown option %s\n",*argv);
+			BIO_printf(bio_err,"unknown option %s\n",*argv);
 			badops=1;
 			break;
 			}
@@ -126,12 +137,12 @@ char **argv;
 	if (badops)
 		{
 bad:
-		fprintf(stderr,"%s [options] <infile\n",prog);
-		fprintf(stderr,"where options are\n");
-		fprintf(stderr," -inform arg   input format - one of DER TXT PEM\n");
-		fprintf(stderr," -in arg       inout file\n");
-		fprintf(stderr," -offset arg   offset into file\n");
-		fprintf(stderr," -length arg   lenth of section in file\n");
+		BIO_printf(bio_err,"%s [options] <infile\n",prog);
+		BIO_printf(bio_err,"where options are\n");
+		BIO_printf(bio_err," -inform arg   input format - one of DER TXT PEM\n");
+		BIO_printf(bio_err," -in arg       inout file\n");
+		BIO_printf(bio_err," -offset arg   offset into file\n");
+		BIO_printf(bio_err," -length arg   lenth of section in file\n");
 		goto end;
 		}
 
@@ -159,83 +170,27 @@ bad:
 	if ((buf=BUF_MEM_new()) == NULL) goto end;
 	if (!BUF_MEM_grow(buf,BUFSIZ*8)) goto end; /* Pre-allocate :-) */
 
-	if (informat == FORMAT_ASN1)
+	if (informat == FORMAT_PEM)
 		{
-		num=0;
-		for (;;)
-			{
-			if (!BUF_MEM_grow(buf,(int)num+BUFSIZ)) goto end;
-			i=BIO_read(in,&(buf->data[num]),BUFSIZ);
-			if (i <= 0) break;
-			num+=i;
-			}
-		}
-	else
-		{
-#define 	LSIZE	(100)
-		EVP_ENCODE_CTX b64;
-		int donesome=0,i,j,tmp;
-		char *p;
+		BIO *tmp;
 
-		EVP_DecodeInit(&b64);
-		num=0;
-		for (;;)
-			{
-			if (!BUF_MEM_grow(buf,(int)num+LSIZE)) goto end;
-			p= &(buf->data[num]);
-			j=BIO_gets(in,p,LSIZE);
-			if (j <= 0)
-				{
-				i=EVP_DecodeFinal(&b64,(unsigned char *)p,&tmp);
-				num+=tmp;
-				break;
-				}
-                        i=EVP_DecodeUpdate(&b64,(unsigned char *)p,&j,
-				(unsigned char *)p,j);
-			num+=j;
-			/* This is to scan until we hit a suitable line */
-			if (i <= 0)
-				{
-				if (!donesome)
-					{
-					num=0;
-					EVP_DecodeInit(&b64);
-					continue;
-					}
-				else
-					{
-					EVP_DecodeFinal(&b64,(unsigned char *)
-						&(buf->data[num]),&i);
-					num+=i;
-					break;
-					}
-				}
-			donesome=1;
-			}
+		if ((b64=BIO_new(BIO_f_base64())) == NULL)
+			goto end;
+		BIO_push(b64,in);
+		tmp=in;
+		in=b64;
+		b64=tmp;
+		}
+
+	num=0;
+	for (;;)
+		{
+		if (!BUF_MEM_grow(buf,(int)num+BUFSIZ)) goto end;
+		i=BIO_read(in,&(buf->data[num]),BUFSIZ);
+		if (i <= 0) break;
+		num+=i;
 		}
 	str=buf->data;
-	buf->data=NULL;
-
-#ifdef undef
-		{
-		char *name=NULL,*header=NULL;
-		EVP_CIPHER_INFO cipher;
-
-		if (!PEM_read(in,&name,&header,(unsigned char **)&str,&num) ||
-		    !PEM_get_EVP_CIPHER_INFO(header,&cipher) ||
-		    !PEM_do_header(&cipher,(unsigned char *)str,&num,NULL))
-			i=0;
-		else
-			i=1;
-		if (name != NULL) free(name);
-		if (header != NULL) free(header);
-		if (!i)
-			{
-			ERR_print_errors(bio_err);
-			goto end;
-			}
-		}
-#endif
 
 	if (length == 0) length=(unsigned int)num;
 	if (!ASN1_parse(out,(unsigned char *)&(str[offset]),length))
@@ -247,10 +202,10 @@ bad:
 end:
 	if (in != NULL) BIO_free(in);
 	if (out != NULL) BIO_free(out);
+	if (b64 != NULL) BIO_free(b64);
 	if (ret != 0)
 		ERR_print_errors(bio_err);
 	if (buf != NULL) BUF_MEM_free(buf);
-	if (str != NULL) free(str);
 	EXIT(ret);
 	}
 
