@@ -1,17 +1,22 @@
 /* apps/genrsa.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -98,7 +109,7 @@ char **argv;
 			BIO_set_fp(bio_err,stderr,BIO_NOCLOSE);
 	if ((out=BIO_new(BIO_s_file())) == NULL)
 		{
-		fprintf(stderr,"unable to creat BIO for output\n");
+		BIO_printf(bio_err,"unable to creat BIO for output\n");
 		goto err;
 		}
 
@@ -137,18 +148,18 @@ char **argv;
 	if ((argc >= 1) && ((sscanf(*argv,"%d",&num) == 0) || (num < 0)))
 		{
 bad:
-		fprintf(stderr,"usage: genrsa [args] [numbits]\n");
-		fprintf(stderr," -des      - encrypt the generated key with DES in cbc mode\n");
-		fprintf(stderr," -des3     - encrypt the generated key with DES in ede cbc mode (168 bit key)\n");
+		BIO_printf(bio_err,"usage: genrsa [args] [numbits]\n");
+		BIO_printf(bio_err," -des      - encrypt the generated key with DES in cbc mode\n");
+		BIO_printf(bio_err," -des3     - encrypt the generated key with DES in ede cbc mode (168 bit key)\n");
 #ifndef NO_IDEA
-		fprintf(stderr," -idea     - encrypt the generated key with IDEA in cbc mode\n");
+		BIO_printf(bio_err," -idea     - encrypt the generated key with IDEA in cbc mode\n");
 #endif
-		fprintf(stderr," -out file - output the key to 'file\n");
-		fprintf(stderr," -f4       - use F4 (0x10001) for the E value\n");
-		fprintf(stderr," -3        - use 3 for the E value\n");
-		fprintf(stderr," -rand file:file:...\n");
-		fprintf(stderr,"           - load the file (or the files in the directory) into\n");
-		fprintf(stderr,"             the random number generator\n");
+		BIO_printf(bio_err," -out file - output the key to 'file\n");
+		BIO_printf(bio_err," -f4       - use F4 (0x10001) for the E value\n");
+		BIO_printf(bio_err," -3        - use 3 for the E value\n");
+		BIO_printf(bio_err," -rand file:file:...\n");
+		BIO_printf(bio_err,"           - load the file (or the files in the directory) into\n");
+		BIO_printf(bio_err,"             the random number generator\n");
 		goto err;
 		}
 		
@@ -164,18 +175,24 @@ bad:
 			}
 		}
 
+#ifdef WINDOWS
+	BIO_printf(bio_err,"Loading 'screen' into random state -");
+	BIO_flush(bio_err);
+	RAND_screen();
+	BIO_printf(bio_err," done\n");
+#endif
 	randfile=RAND_file_name(buffer,200);
 	if ((randfile == NULL) ||
 		 !(rnum=(long)RAND_load_file(randfile,1024L*1024L)))
 		{
-		fprintf(stderr,"unable to load 'random state'\n");
+		BIO_printf(bio_err,"unable to load 'random state'\n");
 		}
 
 	if (inrand == NULL)
 		{
 		if (rnum == 0)
 			{
-			fprintf(stderr,"warning, not much extra random data, consider using the -rand option\n");
+			BIO_printf(bio_err,"warning, not much extra random data, consider using the -rand option\n");
 			}
 		}
 	else
@@ -183,14 +200,14 @@ bad:
 		rnum+=gr_load_rand(inrand);
 		}
 	if (rnum != 0)
-		fprintf(stderr,"%ld semi-random bytes loaded\n",rnum);
+		BIO_printf(bio_err,"%ld semi-random bytes loaded\n",rnum);
 
-	fprintf(stderr,"Generating RSA private key, %d bit long modulus\n",
+	BIO_printf(bio_err,"Generating RSA private key, %d bit long modulus\n",
 		num);
 	rsa=RSA_generate_key(num,f4,genrsa_cb);
 		
 	if (randfile == NULL)
-		fprintf(stderr,"unable to write 'random state'\n");
+		BIO_printf(bio_err,"unable to write 'random state'\n");
 	else
 		RAND_write_file(randfile);
 
@@ -205,7 +222,7 @@ bad:
 		l<<=BN_BITS4;
 		l+=rsa->e->d[i];
 		}
-	fprintf(stderr,"e is %ld (0x%lX)\n",l,l);
+	BIO_printf(bio_err,"e is %ld (0x%lX)\n",l,l);
 	if (!PEM_write_bio_RSAPrivateKey(out,rsa,enc,NULL,0,NULL))
 		goto err;
 
@@ -222,14 +239,14 @@ static void MS_CALLBACK genrsa_cb(p, n)
 int p;
 int n;
 	{
-	int c='*';
+	char c='*';
 
 	if (p == 0) c='.';
 	if (p == 1) c='+';
 	if (p == 2) c='*';
 	if (p == 3) c='\n';
-	fputc(c,stderr);
-	fflush(stderr);
+	BIO_write(bio_err,&c,1);
+	BIO_flush(bio_err);
 #ifdef LINT
 	p=n;
 #endif
