@@ -14,11 +14,8 @@ extern int x509_main(int argc,char *argv[]);
 extern int genrsa_main(int argc,char *argv[]);
 extern int s_server_main(int argc,char *argv[]);
 extern int s_client_main(int argc,char *argv[]);
-extern int s_filter_main(int argc,char *argv[]);
 extern int speed_main(int argc,char *argv[]);
-extern int hashdir_main(int argc,char *argv[]);
 extern int s_time_main(int argc,char *argv[]);
-extern int s_mult_main(int argc,char *argv[]);
 extern int version_main(int argc,char *argv[]);
 extern int pkcs7_main(int argc,char *argv[]);
 extern int crl2pkcs7_main(int argc,char *argv[]);
@@ -40,11 +37,8 @@ extern int x509_main();
 extern int genrsa_main();
 extern int s_server_main();
 extern int s_client_main();
-extern int s_filter_main();
 extern int speed_main();
-extern int hashdir_main();
 extern int s_time_main();
-extern int s_mult_main();
 extern int version_main();
 extern int pkcs7_main();
 extern int crl2pkcs7_main();
@@ -81,17 +75,10 @@ FUNCTION functions[] = {
 #endif
 #ifndef NO_SOCK
 	{FUNC_TYPE_GENERAL,"s_client",s_client_main},
-#endif
-#ifndef NO_SOCK
-	{FUNC_TYPE_GENERAL,"s_filter",s_filter_main},
 #endif
 	{FUNC_TYPE_GENERAL,"speed",speed_main},
-	{FUNC_TYPE_GENERAL,"hashdir",hashdir_main},
 #ifndef NO_SOCK
 	{FUNC_TYPE_GENERAL,"s_time",s_time_main},
-#endif
-#ifndef NO_SOCK
-	{FUNC_TYPE_GENERAL,"s_mult",s_mult_main},
 #endif
 	{FUNC_TYPE_GENERAL,"version",version_main},
 	{FUNC_TYPE_GENERAL,"pkcs7",pkcs7_main},
@@ -114,6 +101,9 @@ FUNCTION functions[] = {
 #endif
 #ifndef NO_RC2
 	{FUNC_TYPE_CIPHER,"rc2",enc_main},
+#endif
+#ifndef NO_BLOWFISH
+	{FUNC_TYPE_CIPHER,"bf",enc_main},
 #endif
 	{FUNC_TYPE_CIPHER,"des-ecb",enc_main},
 	{FUNC_TYPE_CIPHER,"des-ede",enc_main},
@@ -150,6 +140,18 @@ FUNCTION functions[] = {
 #endif
 #ifndef NO_RC2
 	{FUNC_TYPE_CIPHER,"rc2-ofb",enc_main},
+#endif
+#ifndef NO_BLOWFISH
+	{FUNC_TYPE_CIPHER,"bf-cbc",enc_main},
+#endif
+#ifndef NO_BLOWFISH
+	{FUNC_TYPE_CIPHER,"bf-ecb",enc_main},
+#endif
+#ifndef NO_BLOWFISH
+	{FUNC_TYPE_CIPHER,"bf-cfb",enc_main},
+#endif
+#ifndef NO_BLOWFISH
+	{FUNC_TYPE_CIPHER,"bf-ofb",enc_main},
 #endif
 	{0,NULL,NULL}
 	};
