@@ -1,17 +1,22 @@
 /* apps/speed.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -120,6 +131,9 @@ struct tms {
 #ifndef NO_IDEA
 #include "idea.h"
 #endif
+#ifndef NO_BLOWFISH
+#include "blowfish.h"
+#endif
 #include "rsa.h"
 #include "x509.h"
 #include "./testcert.h"
@@ -221,7 +235,7 @@ char **argv;
 	{
 	unsigned char *buf=NULL;
 	int ret=1;
-#define ALGOR_NUM	12
+#define ALGOR_NUM	10
 #define SIZE_NUM	5
 #define RSA_NUM		4
 	long count;
@@ -237,11 +251,13 @@ char **argv;
 #endif
 #ifndef NO_IDEA
 	IDEA_KEY_SCHEDULE idea_ks;
+#endif
+#ifndef NO_BLOWFISH
+	BF_KEY bf_ks;
 #endif
 	static unsigned char key16[16]=
 		{0x12,0x34,0x56,0x78,0x9a,0xbc,0xde,0xf0,
 		 0x34,0x56,0x78,0x9a,0xbc,0xde,0xf0,0x12};
-	int cfb_state=0;
 	des_cblock iv;
 	static des_cblock key ={0x12,0x34,0x56,0x78,0x9a,0xbc,0xde,0xf0};
 	static des_cblock key2={0x34,0x56,0x78,0x9a,0xbc,0xde,0xf0,0x12};
@@ -252,20 +268,18 @@ char **argv;
 #define	D_SHA		2
 #define	D_SHA1		3
 #define	D_RC4		4
-#define	D_CFB_DES	5
-#define	D_CBC_DES	6
-#define	D_EDE3_DES	7
-#define	D_CFB_IDEA	8
-#define	D_CBC_IDEA	9
-#define	D_CFB_RC2	10
-#define	D_CBC_RC2	11
+#define	D_CBC_DES	5
+#define	D_EDE3_DES	6
+#define	D_CBC_IDEA	7
+#define	D_CBC_RC2	8
+#define	D_CBC_BF	9
 	double d,results[ALGOR_NUM][SIZE_NUM];
 	static int lengths[SIZE_NUM]={8,64,256,1024,8*1024};
 	long c[ALGOR_NUM][SIZE_NUM];
 	static char *names[ALGOR_NUM]={
 		"md2","md5","sha","sha1","rc4",
-		"des cfb","des cbc","des ede3","idea cfb","idea cbc",
-		"rc2 cfb","rc2 cbc"};
+		"des cbc","des ede3","idea cbc",
+		"rc2 cbc","blowfish cbc"};
 #define	R_RSA_512	0
 #define	R_RSA_1024	1
 #define	R_RSA_2048	2
@@ -293,9 +307,9 @@ char **argv;
 	for (i=0; i<RSA_NUM; i++)
 		rsa_key[i]=NULL;
 
-	if ((buf=(unsigned char *)malloc(BUFSIZE)) == NULL)
+	if ((buf=(unsigned char *)Malloc((int)BUFSIZE)) == NULL)
 		{
-		fprintf(stderr,"out of memory\n");
+		BIO_printf(bio_err,"out of memory\n");
 		goto end;
 		}
 
@@ -319,7 +333,6 @@ char **argv;
 #ifndef NO_RC4
 		else if (strcmp(*argv,"rc4") == 0) doit[D_RC4]=1;
 #endif
-		else if (strcmp(*argv,"des-cfb") == 0) doit[D_CFB_DES]=1;
 		else if (strcmp(*argv,"des-cbc") == 0) doit[D_CBC_DES]=1;
 		else if (strcmp(*argv,"des-ede3") == 0) doit[D_EDE3_DES]=1;
 		else if (strcmp(*argv,"rsa512") == 0) rsa_doit[R_RSA_512]=2;
@@ -327,26 +340,19 @@ char **argv;
 		else if (strcmp(*argv,"rsa2048") == 0) rsa_doit[R_RSA_2048]=2;
 		else if (strcmp(*argv,"rsa4096") == 0) rsa_doit[R_RSA_4096]=2;
 #ifndef NO_RC2
-		else if (strcmp(*argv,"rc2-cfb") == 0) doit[D_CFB_RC2]=1;
 		else if (strcmp(*argv,"rc2-cbc") == 0) doit[D_CBC_RC2]=1;
-		else if (strcmp(*argv,"rc2") == 0)
-			{
-			doit[D_CFB_RC2]=1;
-			doit[D_CBC_RC2]=1;
-			}
+		else if (strcmp(*argv,"rc2") == 0) doit[D_CBC_RC2]=1;
 #endif
 #ifndef NO_IDEA
-		else if (strcmp(*argv,"idea-cfb") == 0) doit[D_CFB_IDEA]=1;
 		else if (strcmp(*argv,"idea-cbc") == 0) doit[D_CBC_IDEA]=1;
-		else if (strcmp(*argv,"idea") == 0)
-			{
-			doit[D_CFB_IDEA]=1;
-			doit[D_CBC_IDEA]=1;
-			}
+		else if (strcmp(*argv,"idea") == 0) doit[D_CBC_IDEA]=1;
+#endif
+#ifndef NO_BLOWFISH
+		else if (strcmp(*argv,"bf-cbc") == 0) doit[D_CBC_BF]=1;
+		else if (strcmp(*argv,"blowfish") == 0) doit[D_CBC_BF]=1;
 #endif
 		else if (strcmp(*argv,"des") == 0)
 			{
-			doit[D_CFB_DES]=1;
 			doit[D_CBC_DES]=1;
 			doit[D_EDE3_DES]=1;
 			}
@@ -359,23 +365,26 @@ char **argv;
 			}
 		else
 			{
-			fprintf(stderr,"bad value, pick one of\n");
-			fprintf(stderr,"md2      md5      sha      sha1\n");
+			BIO_printf(bio_err,"bad value, pick one of\n");
+			BIO_printf(bio_err,"md2      md5      sha      sha1\n");
 #ifndef NO_IDEA
-			fprintf(stderr,"idea-cfb idea-cbc ");
+			BIO_printf(bio_err,"idea-cbc ");
 #endif
 #ifndef NO_RC2
-			fprintf(stderr,"rc2-cfb  rc2-cbc");
+			BIO_printf(bio_err,"rc2-cbc  ");
 #endif
-#if !(defined(NO_IDEA) && defined(NO_RC2))
-			fprintf(stderr,"\n");
+#ifndef NO_RC2
+			BIO_printf(bio_err,"bf-cbc");
 #endif
-			fprintf(stderr,"des-cfb  des-cbc  des-ede3 ");
+#if !defined(NO_IDEA) && !defined(NO_RC2) && !defined(NO_BLOWFISH)
+			BIO_printf(bio_err,"\n");
+#endif
+			BIO_printf(bio_err,"des-cbc  des-ede3 ");
 #ifndef NO_RC4
-			fprintf(stderr,"rc4");
+			BIO_printf(bio_err,"rc4");
 #endif
-			fprintf(stderr,"\nrsa512   rsa1024  rsa2048  rsa4096\n");
-			fprintf(stderr,"idea     rc2      des      rsa\n");
+			BIO_printf(bio_err,"\nrsa512   rsa1024  rsa2048  rsa4096\n");
+			BIO_printf(bio_err,"idea     rc2      des      rsa    blowfish\n");
 			goto end;
 			}
 		argc--;
@@ -394,8 +403,8 @@ char **argv;
 		if (doit[i]) pr_header++;
 
 #ifndef TIMES
-	fprintf(stderr,"To get the most accurate results, try to run this\n");
-	fprintf(stderr,"program when this computer is idle.\n");
+	BIO_printf(bio_err,"To get the most accurate results, try to run this\n");
+	BIO_printf(bio_err,"program when this computer is idle.\n");
 #endif
 
 	for (i=0; i<RSA_NUM; i++)
@@ -404,7 +413,7 @@ char **argv;
 		rsa_key[i]=d2i_RSAPrivateKey(NULL,&p,rsa_data_length[i]);
 		if (rsa_key[i] == NULL)
 			{
-			fprintf(stderr,"internal error loading RSA key number %d\n",i);
+			BIO_printf(bio_err,"internal error loading RSA key number %d\n",i);
 			goto end;
 			}
 		}
@@ -418,11 +427,14 @@ char **argv;
 	RC4_set_key(&rc4_ks,16,key16);
 #endif
 #ifndef NO_RC2
-	RC2_set_key(&rc2_ks,16,key16);
+	RC2_set_key(&rc2_ks,16,key16,128);
+#endif
+#ifndef NO_BLOWFISH
+	BF_set_key(&bf_ks,16,key16);
 #endif
 
 #ifndef SIGALRM
-	fprintf(stderr,"First we calculate the approximate speed ...\n");
+	BIO_printf(bio_err,"First we calculate the approximate speed ...\n");
 	count=10;
 	do	{
 		long i;
@@ -438,13 +450,11 @@ char **argv;
 	c[D_SHA][0]=count;
 	c[D_SHA1][0]=count;
 	c[D_RC4][0]=count*5;
-	c[D_CFB_DES][0]=count;
 	c[D_CBC_DES][0]=count;
 	c[D_EDE3_DES][0]=count/3;
 	c[D_CBC_IDEA][0]=count;
-	c[D_CFB_IDEA][0]=count;
 	c[D_CBC_RC2][0]=count;
-	c[D_CFB_RC2][0]=count;
+	c[D_CBC_BF][0]=count;
 
 	for (i=1; i<SIZE_NUM; i++)
 		{
@@ -460,13 +470,11 @@ char **argv;
 		l0=(long)lengths[i-1];
 		l1=(long)lengths[i];
 		c[D_RC4][i]=c[D_RC4][i-1]*l0/l1;
-		c[D_CFB_DES][i]=c[D_CFB_DES][i-1]*l0/l1;
 		c[D_CBC_DES][i]=c[D_CBC_DES][i-1]*l0/l1;
 		c[D_EDE3_DES][i]=c[D_EDE3_DES][i-1]*l0/l1;
 		c[D_CBC_IDEA][i]=c[D_CBC_IDEA][i-1]*l0/l1;
-		c[D_CFB_IDEA][i]=c[D_CFB_IDEA][i-1]*l0/l1;
 		c[D_CBC_RC2][i]=c[D_CBC_RC2][i-1]*l0/l1;
-		c[D_CFB_RC2][i]=c[D_CFB_RC2][i-1]*l0/l1;
+		c[D_CBC_BF][i]=c[D_CBC_BF][i-1]*l0/l1;
 		}
 	rsa_c[R_RSA_512]=count/2000;
 	for (i=1; i<RSA_NUM; i++)
@@ -494,7 +502,7 @@ char **argv;
 			for (count=0,run=1; COND(c[D_MD2][j]); count++)
 				MD2(buf,(unsigned long)lengths[j],&(md2[0]));
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_MD2],d);
 			results[D_MD2][j]=((double)count)/d*lengths[j];
 			}
@@ -509,7 +517,7 @@ char **argv;
 			for (count=0,run=1; COND(c[D_MD5][j]); count++)
 				MD5(buf,(unsigned long)lengths[j],&(md5[0]));
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_MD5],d);
 			results[D_MD5][j]=((double)count)/d*lengths[j];
 			}
@@ -524,7 +532,7 @@ char **argv;
 			for (count=0,run=1; COND(c[D_SHA][j]); count++)
 				SHA(buf,(unsigned long)lengths[j],&(sha[0]));
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_SHA],d);
 			results[D_SHA][j]=((double)count)/d*lengths[j];
 			}
@@ -539,7 +547,7 @@ char **argv;
 			for (count=0,run=1; COND(c[D_SHA1][j]); count++)
 				SHA1(buf,(unsigned long)lengths[j],&(sha[0]));
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_SHA1],d);
 			results[D_SHA1][j]=((double)count)/d*lengths[j];
 			}
@@ -556,29 +564,13 @@ char **argv;
 				RC4(&rc4_ks,(unsigned int)lengths[j],
 					buf,buf);
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_RC4],d);
 			results[D_RC4][j]=((double)count)/d*lengths[j];
 			}
 		}
 #endif
 
-	if (doit[D_CFB_DES])
-		{
-		for (j=0; j<SIZE_NUM; j++)
-			{
-			print_message(names[D_CFB_DES],c[D_CFB_DES][j],lengths[j]);
-			Time_F(START);
-			for (count=0,run=1; COND(c[D_CFB_DES][j]); count++)
-				des_cfb64_encrypt(buf,buf,(long)lengths[j],sch,
-					(C_Block *)&(iv[0]),&cfb_state,DES_ENCRYPT);
-			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
-				count,names[D_CFB_DES],d);
-			results[D_CFB_DES][j]=((double)count)/d*lengths[j];
-			}
-		}
-
 	if (doit[D_CBC_DES])
 		{
 		for (j=0; j<SIZE_NUM; j++)
@@ -591,7 +583,7 @@ char **argv;
 					(long)lengths[j],sch,
 					(C_Block *)&(iv[0]),DES_ENCRYPT);
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_CBC_DES],d);
 			results[D_CBC_DES][j]=((double)count)/d*lengths[j];
 			}
@@ -609,33 +601,13 @@ char **argv;
 					(long)lengths[j],sch,sch2,sch3,
 					(C_Block *)&(iv[0]),DES_ENCRYPT);
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_EDE3_DES],d);
 			results[D_EDE3_DES][j]=((double)count)/d*lengths[j];
 			}
 		}
 
 #ifndef NO_IDEA
-	if (doit[D_CFB_IDEA])
-		{
-		int v=0;
-
-		for (j=0; j<SIZE_NUM; j++)
-			{
-			print_message(names[D_CFB_IDEA],c[D_CFB_IDEA][j],lengths[j]);
-			Time_F(START);
-			for (count=0,run=1; COND(c[D_CFB_IDEA][j]); count++)
-				idea_cfb64_encrypt(buf,buf,
-					(unsigned long)lengths[j],&idea_ks,
-					(unsigned char *)&(iv[0]),
-					&v,IDEA_ENCRYPT);
-			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
-				count,names[D_CFB_IDEA],d);
-			results[D_CFB_IDEA][j]=((double)count)/d*lengths[j];
-			}
-		}
-
 	if (doit[D_CBC_IDEA])
 		{
 		for (j=0; j<SIZE_NUM; j++)
@@ -647,33 +619,13 @@ char **argv;
 					(unsigned long)lengths[j],&idea_ks,
 					(unsigned char *)&(iv[0]),IDEA_ENCRYPT);
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_CBC_IDEA],d);
 			results[D_CBC_IDEA][j]=((double)count)/d*lengths[j];
 			}
 		}
 #endif
 #ifndef NO_RC2
-	if (doit[D_CFB_RC2])
-		{
-		int v=0;
-
-		for (j=0; j<SIZE_NUM; j++)
-			{
-			print_message(names[D_CFB_RC2],c[D_CFB_RC2][j],lengths[j]);
-			Time_F(START);
-			for (count=0,run=1; COND(c[D_CFB_RC2][j]); count++)
-				RC2_cfb64_encrypt(buf,buf,
-					(unsigned long)lengths[j],&rc2_ks,
-					(unsigned char *)&(iv[0]),
-					&v,RC2_ENCRYPT);
-			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
-				count,names[D_CFB_RC2],d);
-			results[D_CFB_RC2][j]=((double)count)/d*lengths[j];
-			}
-		}
-
 	if (doit[D_CBC_RC2])
 		{
 		for (j=0; j<SIZE_NUM; j++)
@@ -685,12 +637,30 @@ char **argv;
 					(unsigned long)lengths[j],&rc2_ks,
 					(unsigned char *)&(iv[0]),RC2_ENCRYPT);
 			d=Time_F(STOP);
-			fprintf(stderr,"%ld %s's in %.2fs\n",
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
 				count,names[D_CBC_RC2],d);
 			results[D_CBC_RC2][j]=((double)count)/d*lengths[j];
 			}
 		}
 #endif
+#ifndef NO_BLOWFISH
+	if (doit[D_CBC_BF])
+		{
+		for (j=0; j<SIZE_NUM; j++)
+			{
+			print_message(names[D_CBC_BF],c[D_CBC_BF][j],lengths[j]);
+			Time_F(START);
+			for (count=0,run=1; COND(c[D_CBC_BF][j]); count++)
+				BF_cbc_encrypt(buf,buf,
+					(unsigned long)lengths[j],&bf_ks,
+					(unsigned char *)&(iv[0]),BF_ENCRYPT);
+			d=Time_F(STOP);
+			BIO_printf(bio_err,"%ld %s's in %.2fs\n",
+				count,names[D_CBC_BF],d);
+			results[D_CBC_BF][j]=((double)count)/d*lengths[j];
+			}
+		}
+#endif
 
 	for (j=0; j<RSA_NUM; j++)
 		{
@@ -701,14 +671,14 @@ char **argv;
 			{
 			if (RSA_private_encrypt(16,buf,buf,rsa_key[j]) < 0)
 				{
-				fprintf(stderr,"RSA private encrypt failure\n");
+				BIO_printf(bio_err,"RSA private encrypt failure\n");
 				ERR_print_errors(bio_err);
 				count=1;
 				break;
 				}
 			}
 		d=Time_F(STOP);
-		fprintf(stderr,"%ld %d bit RSA's in %.2fs\n",
+		BIO_printf(bio_err,"%ld %d bit RSA's in %.2fs\n",
 			count,rsa_bits[j],d);
 		rsa_results[j]=d/(double)count;
 		if (count <= 1)
@@ -727,7 +697,7 @@ char **argv;
 	if (pr_header)
 		{
 		fprintf(stdout,"The 'numbers' are in 1000s of bytes per second processed.\n"); 
-		fprintf(stdout,"type     ");
+		fprintf(stdout,"type        ");
 		for (j=0;  j<SIZE_NUM; j++)
 			fprintf(stdout,"%7d bytes",lengths[j]);
 		fprintf(stdout,"\n");
@@ -736,7 +706,7 @@ char **argv;
 	for (k=0; k<ALGOR_NUM; k++)
 		{
 		if (!doit[k]) continue;
-		fprintf(stdout,"%-9s",names[k]);
+		fprintf(stdout,"%-12s",names[k]);
 		for (j=0; j<SIZE_NUM; j++)
 			{
 			if (results[k][j] > 10000)
@@ -755,7 +725,7 @@ char **argv;
 		}
 	ret=0;
 end:
-	if (buf != NULL) free(buf);
+	if (buf != NULL) Free(buf);
 	for (i=0; i<RSA_NUM; i++)
 		if (rsa_key[i] != NULL)
 			RSA_free(rsa_key[i]);
@@ -768,12 +738,12 @@ long num;
 int length;
 	{
 #ifdef SIGALRM
-	fprintf(stderr,"Doing %s for %ds on %d size blocks: ",s,SECONDS,length);
-	fflush(stderr);
+	BIO_printf(bio_err,"Doing %s for %ds on %d size blocks: ",s,SECONDS,length);
+	BIO_flush(bio_err);
 	alarm(SECONDS);
 #else
-	fprintf(stderr,"Doing %s %ld times on %d size blocks: ",s,num,length);
-	fflush(stderr);
+	BIO_printf(bio_err,"Doing %s %ld times on %d size blocks: ",s,num,length);
+	BIO_flush(bio_err);
 #endif
 #ifdef LINT
 	num=num;
@@ -785,12 +755,12 @@ long num;
 int bits;
 	{
 #ifdef SIGALRM
-	fprintf(stderr,"Doing %d bit rsa's for %ds: ",bits,RSA_SECONDS);
-	fflush(stderr);
+	BIO_printf(bio_err,"Doing %d bit rsa's for %ds: ",bits,RSA_SECONDS);
+	BIO_flush(bio_err);
 	alarm(RSA_SECONDS);
 #else
-	fprintf(stderr,"Doing %ld %d bit rsa's: ",num,bits);
-	fflush(stderr);
+	BIO_printf(bio_err,"Doing %ld %d bit rsa's: ",num,bits);
+	BIO_flush(bio_err);
 #endif
 #ifdef LINT
 	num=num;
