@@ -1,17 +1,22 @@
 /* crypto/asn1/a_print.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -65,48 +76,48 @@ B_ASN1_UNIVERSALSTRING,0,0,0,
 	};
 
 int i2d_ASN1_IA5STRING(a,pp)
-ASN1_BIT_STRING *a;
+ASN1_IA5STRING *a;
 unsigned char **pp;
 	{ return(M_i2d_ASN1_IA5STRING(a,pp)); }
 
 ASN1_IA5STRING *d2i_ASN1_IA5STRING(a,pp,l)
-ASN1_BIT_STRING **a;
+ASN1_IA5STRING **a;
 unsigned char **pp;
 long l;
 	{ return(M_d2i_ASN1_IA5STRING(a,pp,l)); }
 
 ASN1_T61STRING *d2i_ASN1_T61STRING(a,pp,l)
-ASN1_BIT_STRING **a;
+ASN1_T61STRING **a;
 unsigned char **pp;
 long l;
 	{ return(M_d2i_ASN1_T61STRING(a,pp,l)); }
 
 ASN1_PRINTABLESTRING *d2i_ASN1_PRINTABLESTRING(a,pp,l)
-ASN1_BIT_STRING **a;
+ASN1_PRINTABLESTRING **a;
 unsigned char **pp;
 long l;
 	{ return(M_d2i_ASN1_PRINTABLESTRING(a,pp,l)); }
 
 int i2d_ASN1_PRINTABLE(a,pp)
-ASN1_BIT_STRING *a;
+ASN1_STRING *a;
 unsigned char **pp;
 	{ return(M_i2d_ASN1_PRINTABLE(a,pp)); }
 
-ASN1_BIT_STRING *d2i_ASN1_PRINTABLE(a,pp,l)
-ASN1_BIT_STRING **a;
+ASN1_STRING *d2i_ASN1_PRINTABLE(a,pp,l)
+ASN1_STRING **a;
 unsigned char **pp;
 long l;
 	{ return(M_d2i_ASN1_PRINTABLE(a,pp,l)); }
 
 /* type is a 'bitmap' of acceptable string types to be accepted.
  */
-ASN1_BIT_STRING *d2i_asn1_print_type(a, pp, length, type)
-ASN1_BIT_STRING **a;
+ASN1_STRING *d2i_asn1_print_type(a, pp, length, type)
+ASN1_STRING **a;
 unsigned char **pp;
 long length;
 int type;
 	{
-	ASN1_BIT_STRING *ret=NULL;
+	ASN1_STRING *ret=NULL;
 	unsigned char *p,*s;
 	long len;
 	int inf,tag,xclass;
@@ -114,14 +125,14 @@ int type;
 
 	if ((a == NULL) || ((*a) == NULL))
 		{
-		if ((ret=ASN1_BIT_STRING_new()) == NULL) return(NULL);
+		if ((ret=ASN1_STRING_new()) == NULL) return(NULL);
 		}
 	else
 		ret=(*a);
 
 	p= *pp;
 	inf=ASN1_get_object(&p,&len,&tag,&xclass,length);
-	if (inf == 0xff) goto err;
+	if (inf & 0x80) goto err;
 
 	if (tag >= 32)
 		{
@@ -168,8 +179,8 @@ int type;
 	return(ret);
 err:
 	ASN1err(ASN1_F_D2I_ASN1_PRINT_TYPE,i);
-	if ((ret != NULL) && (a != NULL) && (*a != ret))
-		ASN1_BIT_STRING_free(ret);
+	if ((ret != NULL) && ((a == NULL) || (*a != ret)))
+		ASN1_STRING_free(ret);
 	return(NULL);
 	}
 
