@@ -1,17 +1,22 @@
 /* crypto/asn1/a_set.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -69,7 +80,7 @@ int ex_class;
 	r=ASN1_object_size(1,ret,ex_tag);
 	if (pp == NULL) return(r);
 
-	p=*pp;
+	p= *pp;
 	ASN1_put_object(&p,1,ret,ex_tag,ex_class);
 	for (i=0; i<sk_num(a); i++)
 		func(sk_value(a,i),&p);
@@ -98,7 +109,7 @@ int ex_class;
 	c.max=(length == 0)?0:(c.p+length);
 
 	c.inf=ASN1_get_object(&c.p,&c.slen,&c.tag,&c.xclass,c.max-c.p);
-	if (c.inf == 0xff) goto err;
+	if (c.inf & 0x80) goto err;
 	if (ex_class != c.xclass)
 		{
 		ASN1err(ASN1_F_D2I_ASN1_SET,ASN1_R_BAD_CLASS);
@@ -114,7 +125,9 @@ int ex_class;
 		ASN1err(ASN1_F_D2I_ASN1_SET,ASN1_R_LENGTH_ERROR);
 		goto err;
 		}
-	if (c.inf == 0x21)
+	/* check for infinite constructed - it can be as long
+	 * as the amount of data passed to us */
+	if (c.inf == (V_ASN1_CONSTRUCTED+1))
 		c.slen=length+ *pp-c.p;
 	c.max=c.p+c.slen;
 
@@ -130,6 +143,6 @@ int ex_class;
 	*pp=c.p;
 	return(ret);
 err:
-	if ((ret != NULL) && (a != NULL) && (*a != ret)) sk_free(ret);
+	if ((ret != NULL) && ((a == NULL) || (*a != ret))) sk_free(ret);
 	return(NULL);
 	}
