@@ -1,17 +1,22 @@
 /* crypto/buffer/bf_buff.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -95,7 +106,6 @@ BIO *bi;
 
 	ctx=(BIO_F_BUFFER_CTX *)Malloc(sizeof(BIO_F_BUFFER_CTX));
 	if (ctx == NULL) return(0);
-	ctx->bio=NULL;
 	ctx->ibuf=(char *)Malloc(DEFAULT_BUFFER_SIZE);
 	if (ctx->ibuf == NULL) { Free(ctx); return(0); }
 	ctx->obuf=(char *)Malloc(DEFAULT_BUFFER_SIZE);
@@ -139,8 +149,9 @@ int outl;
 	if (out == NULL) return(0);
 	ctx=(BIO_F_BUFFER_CTX *)b->ptr;
 
-	if ((ctx == NULL) || (ctx->bio == NULL)) return(0);
+	if ((ctx == NULL) || (b->next_bio == NULL)) return(0);
 	num=0;
+	b->flags&= ~(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
 
 start:
 	i=ctx->ibuf_len;
@@ -166,9 +177,14 @@ start:
 		{
 		for (;;)
 			{
-			i=BIO_read(ctx->bio,out,outl);
-			if (i < 0) return((num > 0)?num:i);
-			if (i == 0) return(num);
+			i=BIO_read(b->next_bio,out,outl);
+			if (i <= 0)
+				{
+				b->flags|=b->next_bio->flags&
+					(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
+				if (i < 0) return((num > 0)?num:i);
+				if (i == 0) return(num);
+				}
 			num+=i;
 			if (outl == i) return(num);
 			out+=i;
@@ -178,9 +194,14 @@ start:
 	/* else */
 
 	/* we are going to be doing some buffering */
-	i=BIO_read(ctx->bio,ctx->ibuf,ctx->buf_size);
-	if (i < 0) return((num > 0)?num:i);
-	if (i == 0) return(num);
+	i=BIO_read(b->next_bio,ctx->ibuf,ctx->buf_size);
+	if (i <= 0)
+		{
+		b->flags|=b->next_bio->flags&
+			(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
+		if (i < 0) return((num > 0)?num:i);
+		if (i == 0) return(num);
+		}
 	ctx->ibuf_off=0;
 	ctx->ibuf_len=i;
 
@@ -198,8 +219,9 @@ int inl;
 
 	if ((in == NULL) || (inl <= 0)) return(0);
 	ctx=(BIO_F_BUFFER_CTX *)b->ptr;
-	if ((ctx == NULL) || (ctx->bio == NULL)) return(0);
+	if ((ctx == NULL) || (b->next_bio == NULL)) return(0);
 
+	b->flags&= ~(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
 start:
 	i=ctx->buf_size-(ctx->obuf_len+ctx->obuf_off);
 	/* add to buffer and return */
@@ -224,10 +246,15 @@ start:
 		/* we now have a full buffer needing flushing */
 		for (;;)
 			{
-			i=BIO_write(ctx->bio,&(ctx->obuf[ctx->obuf_off]),
+			i=BIO_write(b->next_bio,&(ctx->obuf[ctx->obuf_off]),
 				ctx->obuf_len);
-			if (i < 0) return((num > 0)?num:i);
-			if (i == 0) return(num);
+			if (i <= 0)
+				{
+				b->flags|=b->next_bio->flags&
+					(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
+				if (i < 0) return((num > 0)?num:i);
+				if (i == 0) return(num);
+				}
 			ctx->obuf_off+=i;
 			ctx->obuf_len-=i;
 			if (ctx->obuf_len == 0) break;
@@ -240,9 +267,14 @@ start:
 	/* we now have inl bytes to write */
 	while (inl >= ctx->buf_size)
 		{
-		i=BIO_write(ctx->bio,in,inl);
-		if (i < 0) return((num > 0)?num:i);
-		if (i == 0) return(num);
+		i=BIO_write(b->next_bio,in,inl);
+		if (i <= 0)
+			{
+			b->flags|=b->next_bio->flags&
+				(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
+			if (i < 0) return((num > 0)?num:i);
+			if (i == 0) return(num);
+			}
 		num+=i;
 		in+=i;
 		inl-=i;
@@ -263,8 +295,7 @@ char *ptr;
 	BIO_F_BUFFER_CTX *ctx;
 	long ret=1;
 	char *p1,*p2;
-	int r;
-	BIO **bpp;
+	int r,i;
 
 	ctx=(BIO_F_BUFFER_CTX *)b->ptr;
 
@@ -275,13 +306,20 @@ char *ptr;
 		ctx->ibuf_len=0;
 		ctx->obuf_off=0;
 		ctx->obuf_len=0;
-		if (ctx->bio != NULL)
-			ret=BIO_ctrl(ctx->bio,cmd,num,ptr);
+		if (b->next_bio != NULL)
+			ret=BIO_ctrl(b->next_bio,cmd,num,ptr);
 		break;
 	case BIO_CTRL_INFO:
 		ret=(long)ctx->obuf_len;
 		break;
 	case BIO_CTRL_GET:
+		ret=0;
+		p1=ctx->ibuf;
+		for (i=ctx->ibuf_off; i<ctx->ibuf_len; i++)
+			{
+			if (p1[i] == '\n') ret++;
+			}
+		break;
 	case BIO_CTRL_PENDING:
 		ret=(long)ctx->ibuf_len;
 		break;
@@ -310,22 +348,8 @@ char *ptr;
 				}
 			}
 		break;
-	case BIO_CTRL_PUSH:
-		ctx->bio=(BIO *)ptr;
-		ret=1;
-		break;
-	case BIO_CTRL_POP:
-		bpp=(BIO **)ptr;
-		if ((bpp != NULL) && (*bpp != NULL))
-			{
-			*bpp=ctx->bio;
-			ret=1;
-			}
-		else
-			ret=0;
-		break;
 	case BIO_CTRL_FLUSH:
-		r=BIO_write(ctx->bio,&(ctx->obuf[ctx->obuf_off]),
+		r=BIO_write(b->next_bio,&(ctx->obuf[ctx->obuf_off]),
 			ctx->obuf_len);
 		if (r <= 0) return((long)r);
 		if (r == ctx->obuf_len)
@@ -341,14 +365,14 @@ char *ptr;
 		ret=(long)r;
 		break;
 	default:
-		ret=BIO_ctrl(ctx->bio,cmd,num,ptr);
+		ret=BIO_ctrl(b->next_bio,cmd,num,ptr);
 		break;
 		}
 	return(ret);
 	}
 
-static int buffer_gets(bp,buf,size)
-BIO *bp;
+static int buffer_gets(b,buf,size)
+BIO *b;
 char *buf;
 int size;
 	{
@@ -356,8 +380,9 @@ int size;
 	int num=0,i;
 	char *p;
 
-	ctx=(BIO_F_BUFFER_CTX *)bp->ptr;
+	ctx=(BIO_F_BUFFER_CTX *)b->ptr;
 	size--;
+	b->flags&= ~(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
 
 	for (;;)
 		{
@@ -378,19 +403,24 @@ int size;
 			}
 		else	/* read another chunk */
 			{
-			i=BIO_read(ctx->bio,ctx->ibuf,ctx->buf_size);
-			if (i < 0) return((num > 0)?num:i);
-			if (i == 0) return(num);
+			i=BIO_read(b->next_bio,ctx->ibuf,ctx->buf_size);
+			if (i <= 0)
+				{
+				b->flags|=b->next_bio->flags&
+					(BIO_FLAGS_RW|BIO_FLAGS_SHOULD_RETRY);
+				if (i < 0) return((num > 0)?num:i);
+				if (i == 0) return(num);
+				}
 			ctx->ibuf_len=i;
 			ctx->ibuf_off=0;
 			}
 		}
 	}
 
-static int buffer_puts(bp,str)
-BIO *bp;
+static int buffer_puts(b,str)
+BIO *b;
 char *str;
 	{
-	return(buffer_write(bp,str,strlen(str)));
+	return(buffer_write(b,str,strlen(str)));
 	}
 
