@@ -1,17 +1,22 @@
 /* crypto/conf/conf.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -84,7 +95,7 @@ static CONF_VALUE *get_section();
 
 #define scan_esc(p)	((*(++p) == '\0')?(p):(++p))
 
-char *CONF_version="CONF part of SSLeay 0.6.3 06-Aug-1996";
+char *CONF_version="CONF part of SSLeay 0.6.6b 29-Jun-1998";
 
 LHASH *CONF_load(h,file,line)
 LHASH *h;
@@ -94,7 +105,7 @@ long *line;
 	LHASH *ret=NULL;
 	FILE *in=NULL;
 #define BUFSIZE	512
-	int bufnum=0;
+	int bufnum=0,i;
 	BUF_MEM *buff=NULL;
 	char *s,*p,*end;
 	int n,eline=0;
@@ -118,7 +129,7 @@ long *line;
 		goto err;
 		}
 
-	section=(char *)malloc(10);
+	section=(char *)Malloc(10);
 	if (section == NULL)
 		{
 		CONFerr(CONF_F_CONF_LOAD,ERR_R_MALLOC_FAILURE);
@@ -153,23 +164,43 @@ long *line;
 			CONFerr(CONF_F_CONF_LOAD,ERR_R_BUF_LIB);
 			goto err;
 			}
-		buff->data[bufnum]='\0';
-		fgets(&(buff->data[bufnum]),BUFSIZE-1,in);
-		buff->data[bufnum+BUFSIZE-1]='\0';
-		bufnum+=strlen(&(buff->data[bufnum]));
-		if (bufnum == 0) break;
+		p= &(buff->data[bufnum]);
+		*p='\0';
+		fgets(p,BUFSIZE-1,in);
+		p[BUFSIZE-1]='\0';
+		i=strlen(p);
+		if (i == 0) break;
+		while (i > 0)
+			{
+			if ((p[i-1] != '\r') && (p[i-1] != '\n'))
+				break;
+			else
+				i--;
+			}
+		p[i++]='\n';
+		p[i]='\0';
+
+		bufnum+=i;
 		eline++;
 
 		v=NULL;
 		/* check for line continuation */
 		if (bufnum >= 2)
 			{
+			int n=0;
+
 			p= &(buff->data[bufnum-1]);
-			while ((p != buff->data) && (IS_WS(*p)))
+			while ((p != buff->data) && (*p == '\n'))
+				{
+				n++;
 				p--;
-			if (	((p >= buff->data) && (*p == '\\')) &&
-				((p == buff->data) || (p[-1] != '\\')))
+				}
+			if (	((p >= buff->data) && IS_ESC(*p)) &&
+				((p == buff->data) || !IS_ESC(p[-1])))
+				{
+				bufnum-=n;
 				continue; 
+				}
 			}
 		bufnum=0;
 		buf=buff->data;
@@ -231,13 +262,13 @@ long *line;
 			p++;
 			*p='\0';
 
-			if ((v=(CONF_VALUE *)malloc(sizeof(CONF_VALUE))) == NULL)
+			if ((v=(CONF_VALUE *)Malloc(sizeof(CONF_VALUE))) == NULL)
 				{
 				CONFerr(CONF_F_CONF_LOAD,ERR_R_MALLOC_FAILURE);
 				goto err;
 				}
 			if (psection == NULL) psection=section;
-			v->name=(char *)malloc(strlen(pname)+1);
+			v->name=(char *)Malloc(strlen(pname)+1);
 			v->value=NULL;
 			if (v->name == NULL)
 				{
@@ -272,25 +303,30 @@ long *line;
 				}
 			vv=(CONF_VALUE *)lh_insert(ret,(char *)v);
 			if (vv != NULL)
-				abort(); /* vv should be NULL allways */
+				{
+				sk_delete_ptr(ts,(char *)vv);
+				Free(vv->name);
+				Free(vv->value);
+				Free(vv);
+				}
 			v=NULL;
 			}
 		}
 	if (buff != NULL) BUF_MEM_free(buff);
-	if (section != NULL) free(section);
+	if (section != NULL) Free(section);
 	if (in != NULL) fclose(in);
 	return(ret);
 err:
 	if (buff != NULL) BUF_MEM_free(buff);
-	if (section != NULL) free(section);
+	if (section != NULL) Free(section);
 	if (line != NULL) *line=eline;
 	if (in != NULL) fclose(in);
 	if ((h != ret) && (ret != NULL)) CONF_free(ret);
 	if (v != NULL)
 		{
-		if (v->name != NULL) free(v->name);
-		if (v->value != NULL) free(v->value);
-		if (v != NULL) free(v);
+		if (v->name != NULL) Free(v->name);
+		if (v->value != NULL) Free(v->value);
+		if (v != NULL) Free(v);
 		}
 	return(NULL);
 	}
@@ -381,7 +417,7 @@ LHASH *conf;
 	{
 	if (conf == NULL) return;
 
-	conf->down_load=0; 	/* evil thing to make sure the 'free()'
+	conf->down_load=0; 	/* evil thing to make sure the 'Free()'
 				 * works as expected */
 	lh_doall_arg(conf,(void (*)())value_free_hash,(char *)conf);
 
@@ -416,13 +452,13 @@ LHASH *conf;
 	for (i=sk_num(sk)-1; i>=0; i--)
 		{
 		vv=(CONF_VALUE *)sk_value(sk,i);
-		free(vv->value);
-		free(vv->name);
-		free(vv);
+		Free(vv->value);
+		Free(vv->name);
+		Free(vv);
 		}
 	if (sk != NULL) sk_free(sk);
-	free(a->section);
-	free(a);
+	Free(a->section);
+	Free(a);
 	}
 
 static void clear_comments(p)
@@ -461,7 +497,7 @@ char *section;
 char **pto,*from;
 	{
 	int q,r,rr=0,to=0,len=0;
-	char *s,*e,*rp,*p,*rrp,*np,*cp;
+	char *s,*e,*rp,*p,*rrp,*np,*cp,v;
 	BUF_MEM *buf;
 
 	if ((buf=BUF_MEM_new()) == NULL) return(0);
@@ -488,8 +524,13 @@ char **pto,*from;
 		else if (*from == '\\')
 			{
 			from++;
-			if (*from == '\0') break;
-			buf->data[to++]= *(from++);
+			v= *(from++);
+			if (v == '\0') break;
+			else if (v == 'r') v='\r';
+			else if (v == 'n') v='\n';
+			else if (v == 'b') v='\b';
+			else if (v == 't') v='\t';
+			buf->data[to++]= v;
 			}
 		else if (*from == '\0')
 			break;
@@ -558,9 +599,9 @@ char **pto,*from;
 			buf->data[to++]= *(from++);
 		}
 	buf->data[to]='\0';
-	if (*pto != NULL) free(*pto);
+	if (*pto != NULL) Free(*pto);
 	*pto=buf->data;
-	free(buf);
+	Free(buf);
 	return(1);
 err:
 	if (buf != NULL) BUF_MEM_free(buf);
@@ -648,10 +689,10 @@ char *section;
 
 	if ((sk=sk_new_null()) == NULL)
 		goto err;
-	if ((v=(CONF_VALUE *)malloc(sizeof(CONF_VALUE))) == NULL)
+	if ((v=(CONF_VALUE *)Malloc(sizeof(CONF_VALUE))) == NULL)
 		goto err;
 	i=strlen(section)+1;
-	if ((v->section=(char *)malloc(i)) == NULL)
+	if ((v->section=(char *)Malloc(i)) == NULL)
 		goto err;
 
 	memcpy(v->section,section,i);
@@ -671,7 +712,7 @@ err:
 	if (!ok)
 		{
 		if (sk != NULL) sk_free(sk);
-		if (v != NULL) free(v);
+		if (v != NULL) Free(v);
 		v=NULL;
 		}
 	return(v);
