@@ -1,17 +1,22 @@
 /* crypto/cryptlib.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -60,7 +71,12 @@
 #else
 #include "des.h"
 #endif
+#ifndef NO_IDEA
 #include "idea.h"
+#endif
+#ifndef NO_BLOWFISH
+#include "blowfish.h"
+#endif
 #include "crypto.h"
 #include "date.h"
 
@@ -91,7 +107,7 @@ char *SSLeay_version(t)
 int t;
 	{
 	if (t == SSLEAY_VERSION)
-		return("SSLeay 0.6.4 30-Aug-1996");
+		return("SSLeay 0.6.6b 29-Jun-1998");
 	if (t == SSLEAY_OPTIONS)
 		{
 		static char buf[100];
@@ -104,7 +120,12 @@ int t;
 #ifndef NO_DES
 		sprintf(&buf[strlen(buf)],"%s ",des_options());
 #endif
-		sprintf(&buf[strlen(buf)],"%s",idea_options());
+#ifndef NO_IDEA
+		sprintf(&buf[strlen(buf)],"%s ",idea_options());
+#endif
+#ifndef NO_BLOWFISH
+		sprintf(&buf[strlen(buf)],"%s",BF_options());
+#endif
 		return(buf);
 		}
 	if (t == SSLEAY_BUILT_ON)
@@ -190,9 +211,9 @@ unsigned long CRYPTO_thread_id()
 		{
 #ifdef WIN16
 		ret=(unsigned long)GetCurrentTask();
-#elif WIN32
+#elif defined(WIN32)
 		ret=(unsigned long)GetCurrentThreadId();
-#elif MSDOS
+#elif defined(MSDOS)
 		ret=1L;
 #else
 		ret=(unsigned long)getpid();
