@@ -1,17 +1,22 @@
 /* crypto/evp/envelope.h */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -48,7 +59,7 @@
 #ifndef HEADER_ENVELOPE_H
 #define HEADER_ENVELOPE_H
 
-#ifdef  __cplusplus
+#ifdef	__cplusplus
 extern "C" {
 #endif
 
@@ -74,12 +85,16 @@ extern "C" {
 #ifndef NO_RC2
 #include "rc2.h"
 #endif
+#ifndef NO_BLOWFISH
+#include "blowfish.h"
+#endif
 #ifndef NO_IDEA
 #include "idea.h"
 #endif
 
 #define EVP_RC2_KEY_SIZE	16
 #define EVP_RC4_KEY_SIZE	16
+#define EVP_BLOWFISH_KEY_SIZE	16
 #define EVP_MAX_MD_SIZE		20
 #define EVP_MAX_KEY_LENGTH	24
 #define EVP_MAX_IV_LENGTH	8
@@ -97,21 +112,21 @@ extern "C" {
 #define EVP_PKEY_DH	NID_dhKeyAgreement
 
 typedef struct evp_pkey_st
-        {
-        int type;
+	{
+	int type;
 	int references;
-        union   {
-                char *ptr;
-                RSA *rsa;
-                DSA *dsa;
-                DH *dh;
-                } pkey;
+	union	{
+		char *ptr;
+		RSA *rsa;
+		DSA *dsa;
+		DH *dh;
+		} pkey;
 #ifdef HEADER_STACK_H
-        STACK /* X509_ATTRIBUTE */ *attributes; /* [ 0 ] */
+	STACK /* X509_ATTRIBUTE */ *attributes; /* [ 0 ] */
 #else
-        char /* X509_ATTRIBUTE */ *attributes; /* [ 0 ] */
+	char /* X509_ATTRIBUTE */ *attributes; /* [ 0 ] */
 #endif
-        } EVP_PKEY;
+		} EVP_PKEY;
 
 #ifndef EVP_MD
 typedef struct env_md_st
@@ -252,23 +267,54 @@ typedef struct evp_cipher_ctx_st
 			RC2_KEY ks;/* key schedule */
 			int num;	/* used by cfb mode */
 			} rc2_cfb;
+#endif
+#ifndef NO_BLOWFISH
+		struct
+			{
+			BF_KEY ks;/* key schedule */
+			} bf_ecb;
+		struct
+			{
+			unsigned char oiv[8];/* original iv */
+			unsigned char iv[8]; /* working iv */
+			BF_KEY ks;/* key schedule */
+			} bf_cbc;
+		struct
+			{
+			unsigned char oiv[8];/* original iv */
+			unsigned char iv[8]; /* working iv */
+			BF_KEY ks;/* key schedule */
+			int num;	/* used by cfb mode */
+			} bf_cfb;
 #endif
 		} c;
 	} EVP_CIPHER_CTX;
 
 typedef struct evp_Encode_Ctx_st
 	{
-	int num;        /* number saved in a partial encode/decode */
+	int num;	/* number saved in a partial encode/decode */
 	int length;	/* The length is either the output line length
 			 * (in input bytes) or the shortest input line
 			 * length that is ok.  Once decoding begins,
 			 * the length is adjusted up each time a longer
 			 * line is decoded */
-	unsigned char enc_data[80];     /* data to encode */
+	unsigned char enc_data[80];	/* data to encode */
 	} EVP_ENCODE_CTX;
 
-#define EVP_ENCODE_LENGTH(l)    (((l+2)/3*4)+(l/48+1)*2+80)
-#define EVP_DECODE_LENGTH(l)    ((l+3)/4*3+80)
+#define EVP_MD_size(e)	((e)->md_size)
+
+#define EVP_CIPHER_type(e)		((e)->type)
+#define EVP_CIPHER_block_size(e)	((e)->block_size)
+#define EVP_CIPHER_key_length(e)	((e)->key_len)
+#define EVP_CIPHER_iv_length(e)		((e)->iv_len)
+
+#define EVP_CIPHER_CTX_type(e)		((e)->cipher->type)
+#define EVP_CIPHER_CTX_block_size(e)	((e)->cipher->block_size)
+#define EVP_CIPHER_CTX_key_length(e)	((e)->cipher->key_len)
+#define EVP_CIPHER_CTX_iv_length(e)	((e)->cipher->iv_len)
+
+#define EVP_ENCODE_LENGTH(l)	(((l+2)/3*4)+(l/48+1)*2+80)
+#define EVP_DECODE_LENGTH(l)	((l+3)/4*3+80)
 
 #define EVP_SignInit(a,b)		EVP_DigestInit(a,b)
 #define EVP_SignUpdate(a,b,c)		EVP_DigestUpdate(a,b,c)
@@ -277,20 +323,11 @@ typedef struct evp_Encode_Ctx_st
 #define EVP_OpenUpdate(a,b,c,d,e)	EVP_DecryptUpdate(a,b,c,d,e)
 #define EVP_SealUpdate(a,b,c,d,e)	EVP_EncryptUpdate(a,b,c,d,e)	
 
-#ifdef HEADER_BUFFER_H
-typedef struct bio_f_md_ctx_struct
-	{
-	BIO *bio;		/* the bio for IO */
-	EVP_MD_CTX md_ctx;	/* the digest to use */
-	} BIO_F_MD_CTX;
-#endif
+#define BIO_set_md(b,md)		BIO_ctrl(b,BIO_CTRL_SET,0,(char *)md)
+#define BIO_get_md(b,mdp)		BIO_ctrl(b,BIO_CTRL_GET,0,(char *)mdp)
+#define BIO_get_cipher_status(b)	BIO_ctrl(b,BIO_CTRL_INFO,0,NULL)
 
-#define BIO_B64_GET_DECODE	1
-#define BIO_B64_PUT_ENCODE	1
-#define BIO_B64_GET_ENCODE	2
-#define BIO_B64_PUT_DECODE	2
-
-#define BIO_set_md(b,md)	BIO_ctrl(b,BIO_CTRL_SET,1,(char *)md)
+#define	EVP_Cipher(c,o,i,l)	(c)->cipher->do_cipher((c),(o),(i),(l))
 
 #ifndef NOPROTO
 
@@ -328,7 +365,7 @@ void	EVP_CipherUpdate(EVP_CIPHER_CTX *ctx, unsigned char *out,
 		int *outl, unsigned char *in, int inl);
 int	EVP_CipherFinal(EVP_CIPHER_CTX *ctx, unsigned char *outm, int *outl);
 
-int     EVP_SignFinal(EVP_MD_CTX *ctx,unsigned char *md,unsigned int *s,
+int	EVP_SignFinal(EVP_MD_CTX *ctx,unsigned char *md,unsigned int *s,
 		EVP_PKEY *pkey);
 
 int	EVP_VerifyFinal(EVP_MD_CTX *ctx,unsigned char *sigbuf,
@@ -344,24 +381,35 @@ int	EVP_SealInit(EVP_CIPHER_CTX *ctx, EVP_CIPHER *type, unsigned char **ek,
 		int *ekl, unsigned char *iv,EVP_PKEY **pubk, int npubk);
 void	EVP_SealFinal(EVP_CIPHER_CTX *ctx,unsigned char *out,int *outl);
 
-void    EVP_EncodeInit(EVP_ENCODE_CTX *ctx);
-void    EVP_EncodeUpdate(EVP_ENCODE_CTX *ctx,unsigned char *out,
+void	EVP_EncodeInit(EVP_ENCODE_CTX *ctx);
+void	EVP_EncodeUpdate(EVP_ENCODE_CTX *ctx,unsigned char *out,
 		int *outl,unsigned char *in,int inl);
-void    EVP_EncodeFinal(EVP_ENCODE_CTX *ctx,unsigned char *out,int *outl);
-int     EVP_EncodeBlock(unsigned char *t, unsigned char *f, int n);
+void	EVP_EncodeFinal(EVP_ENCODE_CTX *ctx,unsigned char *out,int *outl);
+int	EVP_EncodeBlock(unsigned char *t, unsigned char *f, int n);
 
-void    EVP_DecodeInit(EVP_ENCODE_CTX *ctx);
-int     EVP_DecodeUpdate(EVP_ENCODE_CTX *ctx,unsigned char *out,int *outl,
+void	EVP_DecodeInit(EVP_ENCODE_CTX *ctx);
+int	EVP_DecodeUpdate(EVP_ENCODE_CTX *ctx,unsigned char *out,int *outl,
 		unsigned char *in, int inl);
-int     EVP_DecodeFinal(EVP_ENCODE_CTX *ctx, unsigned
+int	EVP_DecodeFinal(EVP_ENCODE_CTX *ctx, unsigned
 		char *out, int *outl);
-int     EVP_DecodeBlock(unsigned char *t, unsigned
+int	EVP_DecodeBlock(unsigned char *t, unsigned
 		char *f, int n);
 
 void	ERR_load_EVP_strings(void );
 
 #ifdef HEADER_BUFFER_H
 BIO_METHOD *BIO_f_md(void);
+BIO_METHOD *BIO_f_base64(void);
+BIO_METHOD *BIO_f_cipher(void);
+void BIO_set_cipher(BIO *b,EVP_CIPHER *c,unsigned char *k,
+	unsigned char *i, int encrypt);
+#else
+char *BIO_f_md(void);
+char *BIO_f_base64(void);
+char *BIO_f_cipher(void);
+void BIO_set_cipher(char *b,EVP_CIPHER *c,unsigned char *k,
+	unsigned char *i, int encrypt);
+
 #endif
 
 EVP_MD *EVP_md2(void);
@@ -393,6 +441,10 @@ EVP_CIPHER *EVP_rc2_ecb(void);
 EVP_CIPHER *EVP_rc2_cbc(void);
 EVP_CIPHER *EVP_rc2_cfb(void);
 EVP_CIPHER *EVP_rc2_ofb(void);
+EVP_CIPHER *EVP_bf_ecb(void);
+EVP_CIPHER *EVP_bf_cbc(void);
+EVP_CIPHER *EVP_bf_cfb(void);
+EVP_CIPHER *EVP_bf_ofb(void);
 
 int		EVP_PKEY_size(EVP_PKEY *pkey);
 EVP_PKEY *	EVP_PKEY_new(void);
@@ -403,7 +455,7 @@ int		i2d_PublicKey(EVP_PKEY *a, unsigned char **pp);
 
 EVP_PKEY *	d2i_PrivateKey(int type,EVP_PKEY **a, unsigned char **pp,
 			long length);
-int     	i2d_PrivateKey(EVP_PKEY *a, unsigned char **pp);
+int		i2d_PrivateKey(EVP_PKEY *a, unsigned char **pp);
 
 #else
 
@@ -413,7 +465,7 @@ void		EVP_PKEY_free();
 EVP_PKEY *	d2i_PublicKey();
 int		i2d_PublicKey();
 EVP_PKEY *	d2i_PrivateKey();
-int     	i2d_PrivateKey();
+int		i2d_PrivateKey();
 
 EVP_MD *EVP_get_MDbyname();
 void	EVP_DigestInit();
@@ -433,26 +485,33 @@ int	EVP_DecryptFinal();
 void	EVP_CipherInit();
 void	EVP_CipherUpdate();
 int	EVP_CipherFinal();
-int     EVP_SignFinal();
+int	EVP_SignFinal();
 int	EVP_VerifyFinal();
 int	EVP_OpenInit();
 int	EVP_OpenFinal();
 int	EVP_SealInit();
 void	EVP_SealFinal();
-void    EVP_EncodeInit();
-void    EVP_EncodeUpdate();
-void    EVP_EncodeFinal();
-int     EVP_EncodeBlock();
-void    EVP_DecodeInit();
-int     EVP_DecodeUpdate();
-int     EVP_DecodeFinal();
-int     EVP_DecodeBlock();
+void	EVP_EncodeInit();
+void	EVP_EncodeUpdate();
+void	EVP_EncodeFinal();
+int	EVP_EncodeBlock();
+void	EVP_DecodeInit();
+int	EVP_DecodeUpdate();
+int	EVP_DecodeFinal();
+int	EVP_DecodeBlock();
 
 void	ERR_load_EVP_strings();
 
 #ifdef HEADER_BUFFER_H
 BIO_METHOD *BIO_f_md();
+BIO_METHOD *BIO_f_base64();
+BIO_METHOD *BIO_f_cipher();
+#else
+char *BIO_f_md();
+char *BIO_f_base64();
+char *BIO_f_cipher();
 #endif
+void BIO_set_cipher();
 
 EVP_MD *EVP_md2();
 EVP_MD *EVP_md5();
@@ -483,6 +542,10 @@ EVP_CIPHER *EVP_rc2_ecb();
 EVP_CIPHER *EVP_rc2_cbc();
 EVP_CIPHER *EVP_rc2_cfb();
 EVP_CIPHER *EVP_rc2_ofb();
+EVP_CIPHER *EVP_bf_ecb();
+EVP_CIPHER *EVP_bf_cbc();
+EVP_CIPHER *EVP_bf_cfb();
+EVP_CIPHER *EVP_bf_ofb();
 
 #endif
 
@@ -500,14 +563,11 @@ EVP_CIPHER *EVP_rc2_ofb();
 
 /* Reason codes. */
 #define EVP_R_BAD_DECRYPT				 100
-#define EVP_R_DIGEST_TOO_BIG_FOR_RSA_KEY		 101
-#define EVP_R_IV_TOO_LARGE				 102
-#define EVP_R_PUBLIC_KEY_NOT_RSA			 103
-#define EVP_R_THE_ASN1_OBJECT_IDENTIFIER_IS_NOT_KNOWN_FOR_THIS_MD 104
-#define EVP_R_UNKNOWN_ALGORITHM_TYPE			 105
-#define EVP_R_UNSUPORTED_CIPHER				 106
-#define EVP_R_WRONG_FINAL_BLOCK_LENGTH			 107
-#define EVP_R_WRONG_PUBLIC_KEY_TYPE			 108
+#define EVP_R_IV_TOO_LARGE				 101
+#define EVP_R_PUBLIC_KEY_NOT_RSA			 102
+#define EVP_R_UNSUPORTED_CIPHER				 103
+#define EVP_R_WRONG_FINAL_BLOCK_LENGTH			 104
+#define EVP_R_WRONG_PUBLIC_KEY_TYPE			 105
 
 #ifdef  __cplusplus
 }
