@@ -1,17 +1,22 @@
 /* crypto/pem/pem_lib.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -60,7 +71,7 @@
 #include "des.h"
 #endif
 
-char *PEM_version="PEM part of SSLeay 0.6.3 06-Aug-1996";
+char *PEM_version="PEM part of SSLeay 0.6.6b 29-Jun-1998";
 
 #define MIN_LENGTH	4
 
@@ -127,7 +138,7 @@ int type;
 
 	if (type == PEM_TYPE_ENCRYPTED)
 		str="ENCRYPTED";
-	else if (type == PEM_TYPE_ENCRYPTED)
+	else if (type == PEM_TYPE_MIC_CLEAR)
 		str="MIC-CLEAR";
 	else if (type == PEM_TYPE_MIC_ONLY)
 		str="MIC-ONLY";
@@ -212,9 +223,9 @@ int (*cb)();
 			 (strcmp(name,PEM_STRING_X509_REQ) == 0))
 			)
 			break;
-		free(nm);
-		free(header);
-		free(data);
+		Free(nm);
+		Free(header);
+		Free(data);
 		}
 	if (!PEM_get_EVP_CIPHER_INFO(header,&cipher)) goto err;
 	if (!PEM_do_header(&cipher,data,&len,cb)) goto err;
@@ -231,9 +242,9 @@ int (*cb)();
 	if (ret == NULL)
 		PEMerr(PEM_F_PEM_ASN1_READ_BIO,ERR_R_ASN1_LIB);
 err:
-	free(nm);
-	free(header);
-	free(data);
+	Free(nm);
+	Free(header);
+	Free(data);
 	return(ret);
 	}
 
@@ -294,7 +305,7 @@ int (*callback)();
 
 	dsize=i2d(x,NULL);
 	/* dzise + 8 bytes are needed */
-	data=(unsigned char *)malloc((unsigned int)dsize+20);
+	data=(unsigned char *)Malloc((unsigned int)dsize+20);
 	if (data == NULL)
 		{
 		PEMerr(PEM_F_PEM_ASN1_WRITE_BIO,ERR_R_MALLOC_FAILURE);
@@ -350,7 +361,7 @@ err:
 	memset((char *)&ctx,0,sizeof(ctx));
 	memset(buf,0,PEM_BUFSIZE);
 	memset(data,0,(unsigned int)dsize);
-	free(data);
+	Free(data);
 	return(ret);
 	}
 
@@ -541,7 +552,7 @@ long len;
 			goto err;
 		}
 
-	buf=(unsigned char *)malloc(PEM_BUFSIZE*8);
+	buf=(unsigned char *)Malloc(PEM_BUFSIZE*8);
 	if (buf == NULL)
 		{
 		reason=ERR_R_MALLOC_FAILURE;
@@ -561,7 +572,7 @@ long len;
 		}
 	EVP_EncodeFinal(&ctx,buf,&outl);
 	if ((outl > 0) && (BIO_write(bp,(char *)buf,outl) != outl)) goto err;
-	free(buf);
+	Free(buf);
 	if (	(BIO_write(bp,"-----END ",9) != 9) ||
 		(BIO_write(bp,name,nlen) != nlen) ||
 		(BIO_write(bp,"-----\n",6) != 6))
@@ -618,17 +629,24 @@ long *len;
 		return(0);
 		}
 
+	buf[254]='\0';
 	for (;;)
 		{
-		i=BIO_gets(bp,buf,256);
+		i=BIO_gets(bp,buf,254);
+
 		if (i <= 0)
 			{
 			PEMerr(PEM_F_PEM_READ_BIO,PEM_R_NO_START_LINE);
 			goto err;
 			}
+
+		while ((i >= 0) && (buf[i] <= ' ')) i--;
+		buf[++i]='\n'; buf[++i]='\0';
+
 		if (strncmp(buf,"-----BEGIN ",11) == 0)
 			{
 			i=strlen(&(buf[11]));
+
 			if (strncmp(&(buf[11+i-6]),"-----\n",6) != 0)
 				continue;
 			if (!BUF_MEM_grow(nameB,i+9))
@@ -647,8 +665,12 @@ long *len;
 	headerB->data[0]='\0';
 	for (;;)
 		{
-		i=BIO_gets(bp,buf,256);
+		i=BIO_gets(bp,buf,254);
 		if (i <= 0) break;
+
+		while ((i >= 0) && (buf[i] <= ' ')) i--;
+		buf[++i]='\n'; buf[++i]='\0';
+
 		if (buf[0] == '\n') break;
 		if (!BUF_MEM_grow(headerB,hl+i+9))
 			{ PEMerr(PEM_F_PEM_READ_BIO,ERR_R_MALLOC_FAILURE); goto err; }
@@ -670,8 +692,12 @@ long *len;
 		{
 		for (;;)
 			{
-			i=BIO_gets(bp,buf,256);
+			i=BIO_gets(bp,buf,254);
 			if (i <= 0) break;
+
+			while ((i >= 0) && (buf[i] <= ' ')) i--;
+			buf[++i]='\n'; buf[++i]='\0';
+
 			if (i != 65) end=1;
 			if (strncmp(buf,"-----END ",9) == 0)
 				break;
@@ -687,7 +713,12 @@ long *len;
 			if (end)
 				{
 				buf[0]='\0';
-				BIO_gets(bp,buf,256);
+				i=BIO_gets(bp,buf,254);
+				if (i <= 0) break;
+
+				while ((i >= 0) && (buf[i] <= ' ')) i--;
+				buf[++i]='\n'; buf[++i]='\0';
+
 				break;
 				}
 			}
@@ -707,7 +738,7 @@ long *len;
 		PEMerr(PEM_F_PEM_READ_BIO,PEM_R_BAD_END_LINE);
 		goto err;
 		}
-	
+
 	EVP_DecodeInit(&ctx);
 	i=EVP_DecodeUpdate(&ctx,
 		(unsigned char *)dataB->data,&bl,
@@ -730,9 +761,9 @@ long *len;
 	*header=headerB->data;
 	*data=(unsigned char *)dataB->data;
 	*len=bl;
-	free(nameB);
-	free(headerB);
-	free(dataB);
+	Free(nameB);
+	Free(headerB);
+	Free(dataB);
 	return(1);
 err:
 	BUF_MEM_free(nameB);
@@ -740,4 +771,3 @@ err:
 	BUF_MEM_free(dataB);
 	return(0);
 	}
-
