@@ -1,17 +1,22 @@
 /* crypto/rsa/rsa_enc.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -80,7 +91,7 @@ RSA *rsa;
 		goto err;
 		}
 	
-	buf=(unsigned char *)malloc(num);
+	buf=(unsigned char *)Malloc(num);
 	if (buf == NULL)
 		{
 		RSAerr(RSA_F_RSA_PUBLIC_ENCRYPT,ERR_R_MALLOC_FAILURE);
@@ -127,7 +138,7 @@ err:
 	if (buf != NULL) 
 		{
 		memset(buf,0,num);
-		free(buf);
+		Free(buf);
 		}
 	return(r);
 	}
@@ -153,7 +164,7 @@ RSA *rsa;
 		RSAerr(RSA_F_RSA_PRIVATE_ENCRYPT,RSA_R_DATA_TO_LARGE_FOR_KEY_SIZE);
 		goto err;
 		}
-	buf=(unsigned char *)malloc(num);
+	buf=(unsigned char *)Malloc(num);
 	if (buf == NULL)
 		{
 		RSAerr(RSA_F_RSA_PRIVATE_ENCRYPT,ERR_R_MALLOC_FAILURE);
@@ -201,7 +212,7 @@ err:
 	if (buf != NULL)
 		{
 		memset(buf,0,num);
-		free(buf);
+		Free(buf);
 		}
 	return(r);
 	}
@@ -223,7 +234,7 @@ RSA *rsa;
 
 	num=BN_num_bytes(rsa->n);
 
-	buf=(unsigned char *)malloc(num);
+	buf=(unsigned char *)Malloc(num);
 	if (buf == NULL)
 		{
 		RSAerr(RSA_F_RSA_PRIVATE_DECRYPT,ERR_R_MALLOC_FAILURE);
@@ -270,6 +281,7 @@ RSA *rsa;
 		RSAerr(RSA_F_RSA_PRIVATE_DECRYPT,RSA_R_NULL_BEFORE_BLOCK_MISSING);
 		goto err;
 		}
+
 	if (i < 8)
 		{
 		RSAerr(RSA_F_RSA_PRIVATE_DECRYPT,RSA_R_BAD_PAD_BYTE_COUNT);
@@ -290,7 +302,7 @@ err:
 	if (buf != NULL)
 		{
 		memset(buf,0,num);
-		free(buf);
+		Free(buf);
 		}
 	return(r);
 	}
@@ -311,7 +323,7 @@ RSA *rsa;
 	if (ctx == NULL) goto err;
 
 	num=BN_num_bytes(rsa->n);
-	buf=(unsigned char *)malloc(num);
+	buf=(unsigned char *)Malloc(num);
 	if (buf == NULL)
 		{
 		RSAerr(RSA_F_RSA_PUBLIC_DECRYPT,ERR_R_MALLOC_FAILURE);
@@ -383,7 +395,7 @@ err:
 	if (buf != NULL)
 		{
 		memset(buf,0,num);
-		free(buf);
+		Free(buf);
 		}
 	return(r);
 	}
