@@ -1,17 +1,22 @@
 /* crypto/x509/x509_vrf.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -60,6 +71,7 @@
 #include "md5.h"
 #endif
 #include "rsa.h"
+#include "dsa.h"
 #include "envelope.h"
 #include "x509.h"
 #include "objects.h"
@@ -74,11 +86,7 @@ static int verify();
 static int null_callback();
 #endif
 
-#ifdef DEBUG
-void RSA_print_bytes();
-#endif
-
-char *X509_version="X509 part of SSLeay 0.6.4 30-Aug-1996";
+char *X509_version="X509 part of SSLeay 0.6.6b 29-Jun-1998";
 
 int X509_add_cert_file(ctx,file, type)
 CERTIFICATE_CTX *ctx;
@@ -95,15 +103,9 @@ int type;
 #else
 	in=BIO_new(BIO_s_file_internal_w16());
 #endif
-	if (in == NULL)
+
+	if ((in == NULL) || (BIO_read_filename(in,file) <= 0))
 		{
-		SYSerr(ERR_F_FOPEN,errno);
-		X509err(X509_F_X509_ADD_CERT_FILE,ERR_R_SYS_LIB);
-		goto err;
-		}
-	if (BIO_read_filename(in,file) <= 0)
-		{
-		SYSerr(ERR_F_FOPEN,errno);
 		X509err(X509_F_X509_ADD_CERT_FILE,ERR_R_SYS_LIB);
 		goto err;
 		}
@@ -271,19 +273,22 @@ char *arg;
 			{
 			reason=VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT;
 			ret=(*cb)(0,xs,xi,depth,reason,arg);
+			if (!ret) goto end;
+			xi=xs;
 			}
 		else
 			{
 			reason=VERIFY_ERR_UNABLE_TO_GET_ISSUER;
 			ret=(*cb)(0,xs,xi,depth,reason,arg);
+			goto end;
 			}
-		goto end;
 		}
 
-	if ((pkey=X509_extract_key(xi)) == NULL)
+	if ((pkey=X509_get_pubkey(xi)) == NULL)
 		{
 		reason=VERIFY_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY;
 		ret=(*cb)(0,xs,xi,depth,reason,arg);
+		if (!ret) goto end;
 		}
 
 	if (X509_verify(xs,pkey) <= 0)
@@ -293,7 +298,7 @@ char *arg;
 		if (!ret) goto end;
 		}
 
-	i=X509_cmp_current_time(xs->cert_info->validity->notBefore);
+	i=X509_cmp_current_time(X509_get_notBefore(xs));
 	if (i == 0)
 		{
 		reason=VERIFY_ERR_ERROR_IN_NOT_BEFORE_FIELD;
@@ -307,7 +312,7 @@ char *arg;
 		if (!ret) goto end;
 		}
 
-	i=X509_cmp_current_time(xs->cert_info->validity->notAfter);
+	i=X509_cmp_current_time(X509_get_notAfter(xs));
 	if (i == 0)
 		{
 		reason=VERIFY_ERR_ERROR_IN_NOT_AFTER_FIELD;
@@ -356,15 +361,18 @@ end:
 	return(ret);
 	}
 
-int X509_cmp_current_time(str)
-char *str;
+int X509_cmp_current_time(ctm)
+ASN1_UTCTIME *ctm;
 	{
+	char *str;
+	ASN1_UTCTIME atm;
 	time_t offset;
-	char buff1[100],buff2[100],*p;
+	char buff1[24],buff2[24],*p;
 	int i,j;
 
 	p=buff1;
-	i=strlen(str);
+	i=ctm->length;
+	str=(char *)ctm->data;
 	if ((i < 11) || (i > 15)) return(0);
 	memcpy(p,str,10);
 	p+=10;
@@ -387,7 +395,11 @@ char *str;
 		if (*str == '-')
 			offset-=offset;
 		}
-	X509_gmtime_adj(buff2,offset);
+	atm.type=V_ASN1_UTCTIME;
+	atm.length=sizeof(buff2);
+	atm.data=(unsigned char *)buff2;
+
+	X509_gmtime_adj(&atm,offset);
 
 	i=(buff1[0]-'0')*10+(buff1[1]-'0');
 	if (i < 70) i+=100;
@@ -455,7 +467,7 @@ int n;
 		}
 	}
 
-EVP_PKEY *X509_extract_key(x)
+EVP_PKEY *X509_get_pubkey(x)
 X509 *x;
 	{
 	EVP_PKEY *ret=NULL;
@@ -467,7 +479,43 @@ X509 *x;
 	p=x->cert_info->key->public_key->data;
 	j=x->cert_info->key->public_key->length;
 	if ((ret=d2i_PublicKey(type,NULL,&p,(long)j)) == NULL)
-		X509err(X509_F_X509_EXTRACT_KEY,X509_R_ERR_ASN1_LIB);
+		X509err(X509_F_X509_GET_PUBKEY,X509_R_ERR_ASN1_LIB);
 	return(ret);
 	}
 
+int X509_check_private_key(x,k)
+X509 *x;
+EVP_PKEY *k;
+	{
+	EVP_PKEY *xk=NULL;
+	int ok=0;
+
+	xk=X509_get_pubkey(x);
+	if (xk->type != k->type) goto err;
+	switch (k->type)
+		{
+	case EVP_PKEY_RSA:
+	case EVP_PKEY_RSA2:
+		if (BN_cmp(xk->pkey.rsa->n,k->pkey.rsa->n) != 0) goto err;
+		if (BN_cmp(xk->pkey.rsa->e,k->pkey.rsa->e) != 0) goto err;
+		break;
+	case EVP_PKEY_DSA:
+	case EVP_PKEY_DSA2:
+	case EVP_PKEY_DSA3:
+		if (BN_cmp(xk->pkey.dsa->p,k->pkey.dsa->p) != 0) goto err;
+		if (BN_cmp(xk->pkey.dsa->q,k->pkey.dsa->q) != 0) goto err;
+		if (BN_cmp(xk->pkey.dsa->g,k->pkey.dsa->g) != 0) goto err;
+		break;
+	case EVP_PKEY_DH:
+		/* No idea */
+		goto err;
+	default:
+		goto err;
+		}
+
+	ok=1;
+err:
+	if (xk != NULL) EVP_PKEY_free(xk);
+	return(ok);
+	}
+
