@@ -1,17 +1,22 @@
 /* e_os.h */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
- * 
- * This file is part of an SSL implementation written
+ *
+ * This package is an SSL implementation written
  * by Eric Young (eay@mincom.oz.au).
- * The implementation was written so as to conform with Netscapes SSL
- * specification.  This library and applications are
- * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
- * as long as the following conditions are aheared to.
+ * The implementation was written so as to conform with Netscapes SSL.
+ * 
+ * This library is free for commercial and non-commercial use as long as
+ * the following conditions are aheared to.  The following conditions
+ * apply to all code found in this distribution, be it the RC4, RSA,
+ * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
+ * included with this distribution is covered by the same copyright terms
+ * except that the holder is Tim Hudson (tjh@mincom.oz.au).
  * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.  If this code is used in a product,
- * Eric Young should be given attribution as the author of the parts used.
+ * the code are not to be removed.
+ * If this package is used in a product, Eric Young should be given attribution
+ * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
  * 
@@ -25,7 +30,13 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ *    "This product includes cryptographic software written by
+ *     Eric Young (eay@mincom.oz.au)"
+ *    The word 'cryptographic' can be left out if the rouines from the library
+ *    being used are not cryptographic related :-).
+ * 4. If you include any Windows specific code (or a derivative thereof) from 
+ *    the apps directory (application code) you must include an acknowledgement:
+ *    "This product includes software written by Tim Hudson (tjh@mincom.oz.au)"
  * 
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -91,6 +102,8 @@ extern "C" {
 
 #if defined(WINDOWS) || defined(MSDOS)
 
+#define strncasecmp(a,b,c)	strnicmp((a),(b),(c))
+
 #  ifdef WINDOWS
 #    include <windows.h>
 #    include <stddef.h>
@@ -101,7 +114,12 @@ extern "C" {
 #  include <io.h>
 #  include <fcntl.h>
 
+#if defined(WIN16) && (!defined(MONOLITH) || defined(SSLEAY)) && defined(_WINEXITNOPERSIST)
+#  define EXIT(n)		{ if (n == 0) _wsetexit(_WINEXITNOPERSIST); \
+				return(n); }
+#else
 #  define EXIT(n)		return(n);
+#endif
 #  define LIST_SEPERATOR_CHAR ';'
 #  define X_OK	0
 #  define W_OK	2
@@ -118,7 +136,7 @@ extern "C" {
 #    include <unistd.h>
 #  endif
 
-#  define SSLEAY_CONF	"ssleay.conf"
+#  define SSLEAY_CONF	"ssleay.cnf"
 #  define RFILE		".rand"
 #  define LIST_SEPERATOR_CHAR ':'
 #  ifndef MONOLITH
@@ -137,17 +155,20 @@ extern "C" {
 #ifdef USE_SOCKETS
 #  if defined(WINDOWS) || defined(MSDOS)
       /* windows world */
-#    include <winsock.h>
+
+extern HINSTANCE _hInstance;
 
 #    ifdef NO_SOCK
-#      define SSLeay_Write(a,b,c)     (-1)
-#      define SSLeay_Read(a,b,c)      (-1)
+#      define SSLeay_Write(a,b,c)	(-1)
+#      define SSLeay_Read(a,b,c)	(-1)
+#      define SHUTDOWN(fd)		close(fd)
 #    else
-#      define SSLeay_Write(a,b,c)     send((a),(b),(c),0)
-#      define SSLeay_Read(a,b,c)      recv((a),(b),(c),0)
+#      include <winsock.h>
+#      define SSLeay_Write(a,b,c)	send((a),(b),(c),0)
+#      define SSLeay_Read(a,b,c)	recv((a),(b),(c),0)
+#      define SHUTDOWN(fd)		{ shutdown((fd),0); closesocket(fd); }
 #    endif
 
-#    define SHUTDOWN(fd)    { shutdown((fd),2); closesocket((fd)); }
 
 #  else
 
@@ -182,11 +203,15 @@ extern "C" {
 
 #    define SSLeay_Read(a,b,c)     read((a),(b),(c))
 #    define SSLeay_Write(a,b,c)    write((a),(b),(c))
-#    define SHUTDOWN(fd)    { shutdown((fd),2); close((fd)); }
+#    define SHUTDOWN(fd)    { shutdown((fd),0); close((fd)); }
 #    define INVALID_SOCKET	-1
 #  endif
 #endif
 
+#if defined(THREADS) || defined(sun)
+#define _REENTRANT
+#endif
+
 /***********************************************/
 
 #ifndef NOPROTO
@@ -238,17 +263,9 @@ extern "C" {
 #define MD5_DIGEST_LENGTH 16
 #endif
 
-#ifdef undef
-#ifndef THREADS
-#define CRYPTO_w_lock(type)
-#define CRYPTO_w_unlock(type)
-#define CRYPTO_r_lock(type)
-#define CRYPTO_r_unlock(type)
-#endif
-#endif
-
 #ifdef  __cplusplus
 }
 #endif
 
 #endif
+
