@@ -1,5 +1,5 @@
 /* lib/ssl/ssl_err.c */
-/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
+/* Copyright (C) 1995-1997 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -66,9 +66,12 @@ static ERR_STRING_DATA SSL_str_functs[]=
 {ERR_PACK(0,SSL_F_READ_N,0),	"READ_N"},
 {ERR_PACK(0,SSL_F_REQUEST_CERTIFICATE,0),	"REQUEST_CERTIFICATE"},
 {ERR_PACK(0,SSL_F_SERVER_HELLO,0),	"SERVER_HELLO"},
-{ERR_PACK(0,SSL_F_SSL_ACCEPT,0),	"SSL_accept"},
+{ERR_PACK(0,SSL_F_SSL2_ACCEPT,0),	"SSL2_accept"},
+{ERR_PACK(0,SSL_F_SSL2_CONNECT,0),	"SSL2_connect"},
+{ERR_PACK(0,SSL_F_SSL2_READ,0),	"SSL2_read"},
 {ERR_PACK(0,SSL_F_SSL_CERT_NEW,0),	"SSL_CERT_NEW"},
-{ERR_PACK(0,SSL_F_SSL_CONNECT,0),	"SSL_connect"},
+{ERR_PACK(0,SSL_F_SSL_CHECK_PRIVATE_KEY,0),	"SSL_check_private_key"},
+{ERR_PACK(0,SSL_F_SSL_CTX_CHECK_PRIVATE_KEY,0),	"SSL_CTX_check_private_key"},
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_CERTIFICATE,0),	"SSL_CTX_use_certificate"},
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_CERTIFICATE_ASN1,0),	"SSL_CTX_use_certificate_ASN1"},
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_CERTIFICATE_FILE,0),	"SSL_CTX_use_certificate_file"},
@@ -78,17 +81,9 @@ static ERR_STRING_DATA SSL_str_functs[]=
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_RSAPRIVATEKEY,0),	"SSL_CTX_use_RSAPrivateKey"},
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_RSAPRIVATEKEY_ASN1,0),	"SSL_CTX_use_RSAPrivateKey_ASN1"},
 {ERR_PACK(0,SSL_F_SSL_CTX_USE_RSAPRIVATEKEY_FILE,0),	"SSL_CTX_use_RSAPrivateKey_file"},
-{ERR_PACK(0,SSL_F_SSL_ENC_DES_CBC_INIT,0),	"SSL_ENC_DES_CBC_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_DES_CFB_INIT,0),	"SSL_ENC_DES_CFB_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_DES_EDE3_CBC_INIT,0),	"SSL_ENC_DES_EDE3_CBC_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_IDEA_CBC_INIT,0),	"SSL_ENC_IDEA_CBC_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_NULL_INIT,0),	"SSL_ENC_NULL_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_RC2_CBC_INIT,0),	"SSL_ENC_RC2_CBC_INIT"},
-{ERR_PACK(0,SSL_F_SSL_ENC_RC4_INIT,0),	"SSL_ENC_RC4_INIT"},
-{ERR_PACK(0,SSL_F_SSL_GET_NEW_SESSION,0),	"SSL_GET_NEW_SESSION"},
+{ERR_PACK(0,SSL_F_SSL_ENC_INIT,0),	"SSL_ENC_INIT"},
 {ERR_PACK(0,SSL_F_SSL_MAKE_CIPHER_LIST,0),	"SSL_MAKE_CIPHER_LIST"},
 {ERR_PACK(0,SSL_F_SSL_NEW,0),	"SSL_new"},
-{ERR_PACK(0,SSL_F_SSL_READ,0),	"SSL_read"},
 {ERR_PACK(0,SSL_F_SSL_RSA_PRIVATE_DECRYPT,0),	"SSL_RSA_PRIVATE_DECRYPT"},
 {ERR_PACK(0,SSL_F_SSL_RSA_PUBLIC_ENCRYPT,0),	"SSL_RSA_PUBLIC_ENCRYPT"},
 {ERR_PACK(0,SSL_F_SSL_SESSION_NEW,0),	"SSL_SESSION_new"},
@@ -115,6 +110,7 @@ static ERR_STRING_DATA SSL_str_reasons[]=
 	{
 {SSL_R_BAD_AUTHENTICATION_TYPE           ,"bad authentication type"},
 {SSL_R_BAD_CHECKSUM                      ,"bad checksum"},
+{SSL_R_BAD_DATA_RETURNED_BY_CALLBACK     ,"bad data returned by callback"},
 {SSL_R_BAD_MAC_DECODE                    ,"bad mac decode"},
 {SSL_R_BAD_RESPONSE_ARGUMENT             ,"bad response argument"},
 {SSL_R_BAD_RSA_DECRYPT                   ,"bad rsa decrypt"},
@@ -122,20 +118,24 @@ static ERR_STRING_DATA SSL_str_reasons[]=
 {SSL_R_BAD_SSL_SESSION_ID_LENGTH         ,"bad ssl session id length"},
 {SSL_R_BAD_STATE                         ,"bad state"},
 {SSL_R_BAD_WRITE_RETRY                   ,"bad write retry"},
+{SSL_R_CERTIFICATE_VERIFY_FAILED         ,"certificate verify failed"},
 {SSL_R_CHALLENGE_IS_DIFFERENT            ,"challenge is different"},
 {SSL_R_CIPHER_CODE_TOO_LONG              ,"cipher code too long"},
 {SSL_R_CIPHER_TABLE_SRC_ERROR            ,"cipher table src error"},
 {SSL_R_CONECTION_ID_IS_DIFFERENT         ,"conection id is different"},
 {SSL_R_INVALID_CHALLENGE_LENGTH          ,"invalid challenge length"},
+{SSL_R_NO_CERTIFICATE_ASIGNED            ,"no certificate asigned"},
 {SSL_R_NO_CERTIFICATE_SET                ,"no certificate set"},
 {SSL_R_NO_CERTIFICATE_SPECIFIED          ,"no certificate specified"},
 {SSL_R_NO_CIPHER_LIST                    ,"no cipher list"},
 {SSL_R_NO_CIPHER_MATCH                   ,"no cipher match"},
 {SSL_R_NO_CIPHER_WE_TRUST                ,"no cipher we trust"},
 {SSL_R_NO_PRIVATEKEY                     ,"no privatekey"},
+{SSL_R_NO_PRIVATE_KEY_ASIGNED            ,"no private key asigned"},
 {SSL_R_NO_PUBLICKEY                      ,"no publickey"},
 {SSL_R_NO_READ_METHOD_SET                ,"no read method set"},
 {SSL_R_NO_WRITE_METHOD_SET               ,"no write method set"},
+{SSL_R_NULL_ARGUMENT                     ,"null argument"},
 {SSL_R_NULL_SSL_CTX                      ,"null ssl ctx"},
 {SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE ,"peer did not return a certificate"},
 {SSL_R_PEER_ERROR                        ,"peer error"},
